@@ -13,11 +13,11 @@ Text::Amuse - Perl module to generate HTML and LaTeX documents from Emacs Muse m
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 
 =head1 SYNOPSIS
@@ -76,12 +76,20 @@ sub new {
 
 Accessor to the L<Text::Amuse::Document> object. [Internal]
 
+=head3 file
+
+Accessor to the file passed in the constructor (read-only)
+
 =cut
 
 sub document {
     return shift->{_document_obj};
 }
 
+sub file {
+    return shift->{file};
+}
+
 
 =head2 HTML output
 
@@ -308,6 +316,30 @@ sub language {
     return $self->{_doc_language};
 }
 
+=head3 other_language_codes
+
+Always return undef, because in the current implementation you can't
+switch language in the middle of a text. But could be implemented in
+the future. It should return an arrayref or undef.
+
+=cut
+
+sub other_language_codes {
+    return;
+}
+
+=head3 other_languages
+
+Always return undef. When and if implemented, it should return an
+arrayref or undef.
+
+=cut
+
+
+sub other_languages {
+    return;
+}
+
 =head1 DIFFERENCES WITH THE ORIGINAL EMACS MUSE MARKUP
 
 =head3 Inline markup
